@@ -1,5 +1,5 @@
 from PyQt5 import QtWidgets
-from colorbutton import ColorButton
+from qtwidgets import ColorButton
 
 
 class Window(QtWidgets.QMainWindow):
@@ -7,7 +7,7 @@ class Window(QtWidgets.QMainWindow):
     def __init__(self):
         super().__init__()
 
-        palette = ColorButton()
+        palette = ColorButton(color='red')
         palette.colorChanged.connect(self.show_selected_color)
         self.setCentralWidget(palette)
 
