@@ -1,5 +1,5 @@
 from PySide2 import QtCore, QtGui, QtWidgets
-from paint import Paint
+from qtwidgets import Paint
 
 
 class Window(QtWidgets.QMainWindow):
